@@ -37,7 +37,6 @@ as how many children are in any HASH or ARRAY type.
 
 # Internal perl
 use v5.30.0;
-use feature 'say';
 
 # Internal perl modules (core)
 use strict;
@@ -45,14 +44,13 @@ use warnings;
 
 # Internal perl modules (core,recommended)
 use utf8;
-use open qw(:std :utf8);
 use experimental qw(signatures);
 
 # External modules
-use Carp qw(cluck longmess shortmess);
+use Carp qw(cluck croak longmess shortmess);
 
 # Version of this software
-our $VERSION = '0.005';
+our $VERSION = '0.006';
 
 =head1 METHODS
 
@@ -77,7 +75,6 @@ sub new($class,$input = {}) {
     }, $class;
 
     $self->{tree} = $self->_digest($input);
-
     return $self; 
 }
 
@@ -90,10 +87,28 @@ as it is representative of the parent node.
 
 =cut 
 
+# Reverse this as due to the way the recursion works, the base element is
+# returned first.
 sub paths_list($self) {
     return reverse @{$self->{paths}};
 }
 
+=head2 extract
+
+Return a block of data starting from the point specified.
+
+Accepts 1 argument; the path in the format of a list ['some_node',3,'element']
+
+If you pass a blank or undefined list to the function it will return the entire
+tree, as it will presume you are selecting the root/base node.
+
+=cut
+
+sub extract($self,$path = []) {
+    if (ref($path) ne 'ARRAY') { croak 'Passed non-array value to extract' }
+    croak 'Not implemented';
+}
+
 # This is the main worker routing that loops through the data structure
 sub _digest($self,$tree,$stash = { depth=>0 }) {
     my $type    =   ref($tree) ? ref($tree) : 'ELEMENT';
@@ -104,7 +119,7 @@ sub _digest($self,$tree,$stash = { depth=>0 }) {
     }
 
     # Handle booleans more nicely, I imagine there are more of these to deal with
-    if ($type eq 'JSON::PP::Boolean')   {
+    if ($type =~ m/Bool/i)   {
         $type = 'BOOLEAN';
     }
 
